%define pkg     openssl
%define ver     1.0.1o
%define maj     %(echo %{ver} | cut -d'.' -f1)
%define min     %(echo %{ver} | cut -d'.' -f2)
%define pkg_str %{pkg}%{maj}%{min}


Summary:        The OpenSSL toolkit
Name:           %{pkg_str}
Version:        %{ver}
Release:        1%{?dist}%{?pext}
License:        OpenSSL
Group:          System Environment/Libraries
Source0:        http://www.%{pkg}.org/source/%{pkg}-%{ver}.tar.gz
Patch0:         %{pkg}-1.0.1o-build.patch
Patch1:         %{pkg}-1.0.1o-install.patch
URL:            http://www.%{pkg}.org/
Buildroot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:         The OpenSSL Project
BuildRequires:  gcc44 gmp-devel zlib-devel

%description
The OpenSSL toolkit provides support for secure communications between
machines. It includes a certificate management tool and shared libraries
which provide various cryptographic algorithms and protocols.


%package        devel
Summary:        Development tools for OpenSSL
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig zlib-devel
Conflicts:      %{pkg}-devel < %{version}-%{release}

%description    devel
The %{name}-devel package contains the libraries and header files for
developing software using the OpenSSL toolkit.


%package        engine
Summary:        Additional engines for OpenSSL
Group:          System Environment/Libraries
Requires:       %{name} = %{version}-%{release}

%description    engine
The %{name}-engine package contains additional engines, mostly drivers
for external crypto devices, for the OpenSSL toolkit.


%package        static
Summary:        Static libraries for OpenSSL
Group:          Development/Libraries
Requires:       %{name}-devel = %{version}-%{release}
Conflicts:      %{pkg}-static < %{version}-%{release}

%description    static
The %{name}-static package contains the statically linkable libraries for
the OpenSSL toolkit.


%prep
%setup -q -n %{pkg}-%{ver}
%patch0 -p1
%patch1 -p1

# Fix shlib version
%{__sed} -i -e 's/\(# define SHLIB_VERSION_HISTORY\).*/\1 "%{maj}%{min}"/' \
	    -e 's/\(# define SHLIB_VERSION_NUMBER\).*/\1 "%{ver}"/' \
	    crypto/opensslv.h


%build
export CC="gcc44"
export CFLAGS="${RPM_OPT_FLAGS} -fno-strict-aliasing"

./config \
	--prefix=%{_prefix}                       \
	--libdir=%{_lib}                          \
	--openssldir=%{_sysconfdir}/pki/tls       \
	--enginedir=%{_libdir}/%{pkg_str}/engines \
	no-krb5                                   \
	no-ssl2                                   \
	no-ssl3                                   \
	no-static-engine                          \
	threads                                   \
	zlib                                      \
	shared                                    \
	disable-rc5                               \
	enable-gmp                                \
	enable-md2                                \
	enable-rfc3779                            \
%ifarch x86_64
	enable-ec_nistp_64_gcc_128                \
%endif
	-DOPENSSL_MAX_TLS1_2_CIPHER_LENGTH=50

%{__make} \
	depend all


%check
%{__make} test


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_prefix}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_libdir}/%{pkg_str}

%{__make} \
	INSTALL_PREFIX=${RPM_BUILD_ROOT} \
	MANDIR=%{_mandir}                \
	install

for LIB in libcrypto.so.%{ver} libssl.so.%{ver}; do
  %{__rm}      -f      ${RPM_BUILD_ROOT}%{_libdir}/${LIB}
  %{__install} -m 0755 ${LIB} ${RPM_BUILD_ROOT}%{_libdir}
done

# XXX: Prevent conflicts with system's OpenSSL package
%{__mv} -f  ${RPM_BUILD_ROOT}%{_bindir}/%{pkg}  ${RPM_BUILD_ROOT}%{_bindir}/%{pkg_str}
%{__mv} -f  ${RPM_BUILD_ROOT}%{_libdir}/engines ${RPM_BUILD_ROOT}%{_libdir}/%{pkg_str}

# XXX: Already provided by system's OpenSSL package
%{__rm} -rf ${RPM_BUILD_ROOT}%{_sysconfdir}
%{__rm} -rf ${RPM_BUILD_ROOT}%{_bindir}/c_rehash
%{__rm} -rf ${RPM_BUILD_ROOT}%{_mandir}/man1/CA.pl*

# Cleanup
%{__rm} -f  ${RPM_BUILD_ROOT}%{_libdir}/lib*.so.??


%post -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc ACKNOWLEDGMENTS CHANGES* FAQ INSTALL
%doc LICENSE NEWS PROBLEMS README*
%doc doc/{HOWTO,README,*.el,*.gif,*.html,*.txt}
%{_bindir}/%{pkg_str}
%{_libdir}/libcrypto.so.*
%{_libdir}/libssl.so.*
%dir %{_libdir}/%{pkg_str}
%{_mandir}/man1/*.1*
%{_mandir}/man5/*.5*
%{_mandir}/man7/*.7*

%files devel
%defattr(-,root,root)
%{_includedir}/%{pkg}
%{_libdir}/libcrypto.so
%{_libdir}/libssl.so
%{_libdir}/pkgconfig/libcrypto.pc
%{_libdir}/pkgconfig/libssl.pc
%{_libdir}/pkgconfig/%{pkg}.pc
%{_mandir}/man3/*.3*

%files engine
%defattr(-,root,root)
%dir %{_libdir}/%{pkg_str}/engines
%{_libdir}/%{pkg_str}/engines/lib4758cca.so
%{_libdir}/%{pkg_str}/engines/libaep.so
%{_libdir}/%{pkg_str}/engines/libatalla.so
%{_libdir}/%{pkg_str}/engines/libcapi.so
%{_libdir}/%{pkg_str}/engines/libchil.so
%{_libdir}/%{pkg_str}/engines/libcswift.so
%{_libdir}/%{pkg_str}/engines/libgmp.so
%{_libdir}/%{pkg_str}/engines/libgost.so
%{_libdir}/%{pkg_str}/engines/libnuron.so
%{_libdir}/%{pkg_str}/engines/libpadlock.so
%{_libdir}/%{pkg_str}/engines/libsureware.so
%{_libdir}/%{pkg_str}/engines/libubsec.so

%files static
%defattr(-,root,root)
%{_libdir}/libcrypto.a
%{_libdir}/libssl.a


%changelog
* Thu Jun 18 2015 Peter Pramberger <peterpramb@member.fsf.org> - 1.0.1o-1
- New version (1.0.1o)

* Fri Jan 23 2015 Peter Pramberger <peterpramb@member.fsf.org> - 1.0.1l-1
- New version (1.0.1l)

* Thu Jan 15 2015 Peter Pramberger <peterpramb@member.fsf.org> - 1.0.1k-1
- New version (1.0.1k)

* Fri Oct 17 2014 Peter Pramberger <peterpramb@member.fsf.org> - 1.0.1j-1
- New version (1.0.1j)

* Fri Aug 08 2014 Peter Pramberger <peterpramb@member.fsf.org> - 1.0.1i-1
- New version (1.0.1i)

* Thu Jun 05 2014 Peter Pramberger <peterpramb@member.fsf.org> - 1.0.1h-1
- New version (1.0.1h)

* Mon Apr 28 2014 Peter Pramberger <peterpramb@member.fsf.org> - 1.0.1g-1
- Initial build
